#
# spec file for package python-django-jinja
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define modname django_jinja
Name:           python-django-jinja
Version:        2.11.0
Release:        bp156.1.1
Summary:        Jinja2 templating language integrated in Django
License:        BSD-3-Clause
URL:            https://github.com/niwinz/django-jinja
Source:         https://github.com/niwinz/django-jinja/archive/%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module Jinja2 >= 2.5}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-Jinja2 >= 2.5
BuildArch:      noarch
%python_subpackages

%description
Simple and nonobstructive jinja2 integration with Django.

%prep
%setup -q -n django-jinja-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH="%{buildroot}%{$python_sitelib}" $python testing/runtests.py

%files %{python_files}
%license LICENSE
%doc README.rst CHANGES.adoc
%{python_sitelib}/%{modname}
%{python_sitelib}/%{modname}-%{version}*-info

%changelog
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.11.0:
  * Drop Django 2.2 support, now require >=3.2.
  * Drop Python 3.6 and 3.7 support, now require >=3.8.
  * Add Django 4.1 and 4.2 support.
  * Add Python 3.11 support.
  * Provide a better default template engine NAME than 'backend'
* Sun Jun 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Thu Nov 24 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
- Update to 2.10.2:
  - Fix compatibility with Jinja2 3.1 in tests (#296).
- 2.10.1:
  - Update links in documentation to point to new home of Jinja2 docs (#295).
* Mon May  9 2022 Matej Cepl <mcepl@suse.com>
- Make tests run again.
* Mon May  9 2022 pgajdos@suse.com
- version update to 2.10.0
  Version 2.10.0
  - Fix usage of `unittest` to be ready for Python 3.11 (#288).
  - Fix `default_app_config` deprecation warning for Django 3.2 (#289).
  - Replace Travis with GitHub Actions, dropping `ppc64le` arch tests (#290).
  * Added Python 3.10 to tests (Django supports it if >=3.2.9).
  - Run pyupgrade, remove compatibility code (#291).
  - Add support for Django 4.0, with more old-code cleanup (#292).
  * Remove use of `django.conf.urls.url` in test app (gone in Django 4.0).
  * Set `DEFAULT_AUTO_FIELD` to avoid warnings in test app.
  * Remove `django_jinja.contrib._pipeline` package, which was deprecated in 2015.
  * Drop formal Django 3.0 and 3.1 support.
  * * Projects using these versions should still function until support for 2.2 is dropped.
  - Django 2.2 and Python 3.6 will likely be dropped in the next non-patch release.
  Version 2.9.1
  - Complete config example in the docs now reflects actual project defaults (#286).
  - `get_template` no longer calls `template_name.endswith` twice under the default setup.
  - Rewrite usage and template matching config sections in the docs, to fully explain behavior.
  Version 2.9.0
  - Jinja2 policies now settable via `TEMPLATES[n]['OPTIONS']['policies']` (#285).
  - `makemessages` now respects the `ext.i18n.trimmed` policy,
    will automatically trim jinja `{%% trans %%}` blocks when generating `.po` files.
  Version 2.8.0
  - Upgrade to jinja2 3.0, dropping support for 2.11 and below (#279).
  - Dropped Python 3.5 support.
  Version 2.7.1
  - Fixed `makemessages` command, which in 2.7.0 could not detect `{%% trans %%}` tags in Django templates (#272).
  - Fixed `{%% cache %%}` tag to allow a timeout of `None` (to cache forever), which Django's tag added in 2.0 (#274).
  - Fixed README not displaying in project description at PyPI (#276).
  - Added Django 3.2 support.
  Version 2.7.0
  - Fixed loading template names with backslashes on Windows (#249).
  - Added Django's `json_script` filter for Django 2.1 and higher.
  - Fixed docs site stylesheet.
  - Added Django 3.1 support.
  - Removed Django 1.11 support.
  - Added Python 3.9 (rc1) to test suite.
  - Clarified "not recommended" usage of context processors with django-jinja in the docs.
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.6.0:
  * Fix compatibility issues with Django 3.0, minimum version now 1.11.
* Wed Aug  8 2018 tchvatal@suse.com
- Initial commit, needed by python-django-debug-toolbar
